@@ -31,6 +31,7 @@
 
 static char *link_tmpdir = NULL;
 static LinkNetIdType use_local_host = LINK_NET_ID_IS_FQDN;
+static const char *fixed_host_net_id = NULL;
 
 /*
  * make_local_tmpdir:
@@ -134,6 +135,12 @@ link_get_tmpdir (void)
 
 #if defined(AF_INET) || defined(AF_INET6) || defined (AF_UNIX)
 
+/* hopefully a sufficiently large default NIC count */
+#ifdef DEFAULT_LINC2_IFNUM
+#undef DEFAULT_LINC2_IFNUM
+#endif
+#define DEFAULT_LINC2_IFNUM (32)
+
 static char *
 get_netid(LinkNetIdType which, 
 	  char *buf, 
@@ -142,44 +149,72 @@ get_netid(LinkNetIdType which,
 	if (LINK_NET_ID_IS_LOCAL == which)
 		return strncpy(buf, "localhost", len);
 
-	if (LINK_NET_ID_IS_IPADDR == which) {
+	if ((LINK_NET_ID_IS_IPADDR == which)
+	    || (LINK_NET_ID_IS_CUSTOM == which)) {
 #ifndef G_OS_WIN32
 		struct sockaddr_in *adr = NULL;
-		struct ifreq my_ifreqs[2];
-		struct ifconf my_ifconf;
-		int num, i, sock;
+		struct ifreq *my_ifreqs = NULL;
+		struct ifconf my_ifconf = { 0 };
+		int sock = -1;
+		int num = 0;
+		int i = 0;
 
-		my_ifconf.ifc_len = sizeof(my_ifreqs);
-		my_ifconf.ifc_req = my_ifreqs;
 		sock = socket(AF_INET,SOCK_DGRAM,0);
 		if (-1 == sock) 
 			goto out;
-
+#ifdef SIOCGIFNUM
+		i = ioctl(sock, SIOCGIFNUM, &num);
+		if ((0 > i) || !num) {
+			close(sock);
+			goto out;
+		}
+#else
+		num = DEFAULT_LINC2_IFNUM;
+#endif
+		my_ifconf.ifc_len = sizeof(struct ifreq) * num;
+		my_ifconf.ifc_req = (struct ifreq*)malloc(my_ifconf.ifc_len);
+		if (!my_ifconf.ifc_req) {
+			close(sock);
+			goto out;
+		}
 		if (ioctl(sock,SIOCGIFCONF,&my_ifconf) < 0) {
 			close(sock);
+			free(my_ifconf.ifc_req);
 			goto out;
 		}
 		close(sock);
 
-		num = my_ifconf.ifc_len / sizeof(struct ifreq);
-		if (!num) 
-			goto out;
-
+		my_ifreqs = my_ifconf.ifc_req;
  		for (i = 0; i < num; i++) {
 			adr = (struct sockaddr_in *)&my_ifreqs[i].ifr_ifru.ifru_addr;
-			if (strcmp("127.0.0.1", inet_ntoa(adr->sin_addr)))
+			if (fixed_host_net_id) {
+				if (!strcmp(fixed_host_net_id, inet_ntoa(adr->sin_addr)))
+					break;
+			} else {
+				if (strcmp("127.0.0.1", inet_ntoa(adr->sin_addr)))
+					break;
+			}
+			if (!strcmp("0.0.0.0", inet_ntoa(adr->sin_addr))) {
+				if (i) 
+					adr = (struct sockaddr_in *)&my_ifreqs[--i].ifr_ifru.ifru_addr;
 				break;
+			}
 		}
+		strncpy(buf, (const char*)inet_ntoa(adr->sin_addr), len);
+		free(my_ifconf.ifc_req);
+
 		/* will be 127.0.0.1 anyway, if no other address is defined... */
-		return strncpy(buf, (const char*)inet_ntoa(adr->sin_addr), len);
+		return buf;
 #else
 		SOCKET sock;
 		DWORD nbytes;
 		/* Let's hope 20 interfaces is enough. There doesn't
 		 * seem to be any way to get information about how
 		 * many interfaces there are.
+		 * 
+		 * [Jules] Using the ifnum define instead...
 		 */
-		INTERFACE_INFO interfaces[20]; 
+		INTERFACE_INFO interfaces[DEFAULT_LINC2_IFNUM]; 
 		int i;
 
 		sock = socket (AF_INET, SOCK_DGRAM, IPPROTO_UDP);
@@ -282,6 +317,16 @@ link_use_local_hostname (LinkNetIdType use)
         use_local_host = use;
 }
 
+void 
+link_set_local_hostname (const char *host_id)
+{
+	if (!host_id || !strlen(host_id))
+		return;
+
+	fixed_host_net_id = host_id;
+	use_local_host = LINK_NET_ID_IS_CUSTOM;
+}
+
 /*
  * True if succeeded in mapping, else false.
  */
@@ -1058,6 +1103,22 @@ link_protocol_tcp_setup (int                   fd,
 }
 #endif /* defined(AF_INET) || defined(AF_INET6) */
 
+/*
+ * Comments from bug #422908.
+ * Since version 2.14.9 we now always set the flag
+ * LINK_PROTOCOL_NEEDS_BIND for IPv4 and IPv6.  This was 
+ * changed because on Solaris this bind is needed to open
+ * the ports securely when ORBLocalOnly is being used.  The
+ * maintainers decided it would be best to simply turn the
+ * flag on for all platforms rather than support complicated
+ * ifdefs.  We believe this will not cause any issues.
+ * However, if there is a need to revert, please make sure
+ * that this flag continues to be set for the following 
+ * platforms at minimum:
+ *
+ * IPv4: #if defined (G_OS_WIN32) || defined (__sun)
+ * IPv6: #if defined (__sun)
+ */
 static LinkProtocolInfo static_link_protocols[] = {
 #if defined(AF_INET)
 	{
@@ -1065,12 +1126,7 @@ static LinkProtocolInfo static_link_protocols[] = {
 	AF_INET, 			/* family */
 	sizeof (struct sockaddr_in), 	/* addr_len */
 	IPPROTO_TCP, 			/* stream_proto_num */
-					/* flags */
-#ifdef G_OS_WIN32
-	LINK_PROTOCOL_NEEDS_BIND,
-#else
-	0,
-#endif
+	LINK_PROTOCOL_NEEDS_BIND,       /* flags */
 	link_protocol_tcp_setup, 	/* setup */
 	NULL, 				/* destroy */
 	link_protocol_get_sockaddr_ipv4,/* get_sockaddr */
@@ -1084,7 +1140,7 @@ static LinkProtocolInfo static_link_protocols[] = {
 	AF_INET6, 			/* family */
 	sizeof (struct sockaddr_in6), 	/* addr_len */
 	IPPROTO_TCP, 			/* stream_proto_num */
-	0, 				/* flags */
+        LINK_PROTOCOL_NEEDS_BIND,       /* flags */
 	link_protocol_tcp_setup, 	/* setup */
 	NULL, 				/* destroy */
 	link_protocol_get_sockaddr_ipv6,/* get_sockaddr */
